Class: Google::Cloud::SecureSourceManager::V1::BatchCreatePullRequestCommentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::BatchCreatePullRequestCommentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
The request to batch create pull request comments.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#requests ⇒ ::Array<::Google::Cloud::SecureSourceManager::V1::CreatePullRequestCommentRequest>
Required.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The pull request in which to create the pull request comments.
Format:
projects/{project_number}/locations/{location_id}/repositories/{repository_id}/pullRequests/{pull_request_id}.
1664 1665 1666 1667 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1664 class BatchCreatePullRequestCommentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#requests ⇒ ::Array<::Google::Cloud::SecureSourceManager::V1::CreatePullRequestCommentRequest>
Returns Required. The request message specifying the resources to create. There should be exactly one CreatePullRequestCommentRequest with CommentDetail being REVIEW in the list, and no more than 100 CreatePullRequestCommentRequests with CommentDetail being CODE in the list.
1664 1665 1666 1667 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1664 class BatchCreatePullRequestCommentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |