Class: Google::Cloud::SecureSourceManager::V1::CloseIssueRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::CloseIssueRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
The request to close an issue.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The current etag of the issue. If the etag is provided and does not match the current etag of the issue, closing will be blocked and an ABORTED error will be returned.
1485 1486 1487 1488 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1485 class CloseIssueRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Name of the issue to close.
The format is
projects/{project_number}/locations/{location_id}/repositories/{repository_id}/issues/{issue_id}.
1485 1486 1487 1488 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1485 class CloseIssueRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |