Class: Google::Cloud::SecureSourceManager::V1::Instance
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::Instance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
A resource that represents a Secure Source Manager instance.
Defined Under Namespace
Modules: State, StateNote Classes: HostConfig, LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#host_config ⇒ ::Google::Cloud::SecureSourceManager::V1::Instance::HostConfig
readonly
Output only.
-
#kms_key ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Optional.
-
#state ⇒ ::Google::Cloud::SecureSourceManager::V1::Instance::State
readonly
Output only.
-
#state_note ⇒ ::Google::Cloud::SecureSourceManager::V1::Instance::StateNote
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create timestamp.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 62 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # HostConfig has different instance endpoints. # @!attribute [r] html # @return [::String] # Output only. HTML hostname. # @!attribute [r] api # @return [::String] # Output only. API hostname. This is the hostname to use for **Host: Data # Plane** endpoints. # @!attribute [r] git_http # @return [::String] # Output only. Git HTTP hostname. # @!attribute [r] git_ssh # @return [::String] # Output only. Git SSH hostname. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Secure Source Manager instance state. module State # Not set. This should only be the case for incoming requests. STATE_UNSPECIFIED = 0 # Instance is being created. CREATING = 1 # Instance is ready. ACTIVE = 2 # Instance is being deleted. DELETING = 3 # Instance is paused. PAUSED = 4 end # Provides information about the current instance state. module StateNote # STATE_NOTE_UNSPECIFIED as the first value of State. STATE_NOTE_UNSPECIFIED = 0 # CMEK access is unavailable. PAUSED_CMEK_UNAVAILABLE = 1 # INSTANCE_RESUMING indicates that the instance was previously paused # and is under the process of being brought back. INSTANCE_RESUMING = 2 end end |
#host_config ⇒ ::Google::Cloud::SecureSourceManager::V1::Instance::HostConfig (readonly)
Returns Output only. A list of hostnames for this instance.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 62 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # HostConfig has different instance endpoints. # @!attribute [r] html # @return [::String] # Output only. HTML hostname. # @!attribute [r] api # @return [::String] # Output only. API hostname. This is the hostname to use for **Host: Data # Plane** endpoints. # @!attribute [r] git_http # @return [::String] # Output only. Git HTTP hostname. # @!attribute [r] git_ssh # @return [::String] # Output only. Git SSH hostname. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Secure Source Manager instance state. module State # Not set. This should only be the case for incoming requests. STATE_UNSPECIFIED = 0 # Instance is being created. CREATING = 1 # Instance is ready. ACTIVE = 2 # Instance is being deleted. DELETING = 3 # Instance is paused. PAUSED = 4 end # Provides information about the current instance state. module StateNote # STATE_NOTE_UNSPECIFIED as the first value of State. STATE_NOTE_UNSPECIFIED = 0 # CMEK access is unavailable. PAUSED_CMEK_UNAVAILABLE = 1 # INSTANCE_RESUMING indicates that the instance was previously paused # and is under the process of being brought back. INSTANCE_RESUMING = 2 end end |
#kms_key ⇒ ::String
Returns Optional. Immutable. Customer-managed encryption key name, in the format projects//locations//keyRings//cryptoKeys/.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 62 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # HostConfig has different instance endpoints. # @!attribute [r] html # @return [::String] # Output only. HTML hostname. # @!attribute [r] api # @return [::String] # Output only. API hostname. This is the hostname to use for **Host: Data # Plane** endpoints. # @!attribute [r] git_http # @return [::String] # Output only. Git HTTP hostname. # @!attribute [r] git_ssh # @return [::String] # Output only. Git SSH hostname. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Secure Source Manager instance state. module State # Not set. This should only be the case for incoming requests. STATE_UNSPECIFIED = 0 # Instance is being created. CREATING = 1 # Instance is ready. ACTIVE = 2 # Instance is being deleted. DELETING = 3 # Instance is paused. PAUSED = 4 end # Provides information about the current instance state. module StateNote # STATE_NOTE_UNSPECIFIED as the first value of State. STATE_NOTE_UNSPECIFIED = 0 # CMEK access is unavailable. PAUSED_CMEK_UNAVAILABLE = 1 # INSTANCE_RESUMING indicates that the instance was previously paused # and is under the process of being brought back. INSTANCE_RESUMING = 2 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 62 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # HostConfig has different instance endpoints. # @!attribute [r] html # @return [::String] # Output only. HTML hostname. # @!attribute [r] api # @return [::String] # Output only. API hostname. This is the hostname to use for **Host: Data # Plane** endpoints. # @!attribute [r] git_http # @return [::String] # Output only. Git HTTP hostname. # @!attribute [r] git_ssh # @return [::String] # Output only. Git SSH hostname. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Secure Source Manager instance state. module State # Not set. This should only be the case for incoming requests. STATE_UNSPECIFIED = 0 # Instance is being created. CREATING = 1 # Instance is ready. ACTIVE = 2 # Instance is being deleted. DELETING = 3 # Instance is paused. PAUSED = 4 end # Provides information about the current instance state. module StateNote # STATE_NOTE_UNSPECIFIED as the first value of State. STATE_NOTE_UNSPECIFIED = 0 # CMEK access is unavailable. PAUSED_CMEK_UNAVAILABLE = 1 # INSTANCE_RESUMING indicates that the instance was previously paused # and is under the process of being brought back. INSTANCE_RESUMING = 2 end end |
#name ⇒ ::String
Returns Optional. A unique identifier for an instance. The name should be of the
format:
projects/{project_number}/locations/{location_id}/instances/{instance_id}
project_number: Maps to a unique int64 id assigned to each project.
location_id: Refers to the region where the instance will be deployed.
Since Secure Source Manager is a regional service, it must be one of the
valid GCP regions.
instance_id: User provided name for the instance, must be unique for a
project_number and location_id combination.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 62 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # HostConfig has different instance endpoints. # @!attribute [r] html # @return [::String] # Output only. HTML hostname. # @!attribute [r] api # @return [::String] # Output only. API hostname. This is the hostname to use for **Host: Data # Plane** endpoints. # @!attribute [r] git_http # @return [::String] # Output only. Git HTTP hostname. # @!attribute [r] git_ssh # @return [::String] # Output only. Git SSH hostname. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Secure Source Manager instance state. module State # Not set. This should only be the case for incoming requests. STATE_UNSPECIFIED = 0 # Instance is being created. CREATING = 1 # Instance is ready. ACTIVE = 2 # Instance is being deleted. DELETING = 3 # Instance is paused. PAUSED = 4 end # Provides information about the current instance state. module StateNote # STATE_NOTE_UNSPECIFIED as the first value of State. STATE_NOTE_UNSPECIFIED = 0 # CMEK access is unavailable. PAUSED_CMEK_UNAVAILABLE = 1 # INSTANCE_RESUMING indicates that the instance was previously paused # and is under the process of being brought back. INSTANCE_RESUMING = 2 end end |
#state ⇒ ::Google::Cloud::SecureSourceManager::V1::Instance::State (readonly)
Returns Output only. Current state of the instance.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 62 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # HostConfig has different instance endpoints. # @!attribute [r] html # @return [::String] # Output only. HTML hostname. # @!attribute [r] api # @return [::String] # Output only. API hostname. This is the hostname to use for **Host: Data # Plane** endpoints. # @!attribute [r] git_http # @return [::String] # Output only. Git HTTP hostname. # @!attribute [r] git_ssh # @return [::String] # Output only. Git SSH hostname. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Secure Source Manager instance state. module State # Not set. This should only be the case for incoming requests. STATE_UNSPECIFIED = 0 # Instance is being created. CREATING = 1 # Instance is ready. ACTIVE = 2 # Instance is being deleted. DELETING = 3 # Instance is paused. PAUSED = 4 end # Provides information about the current instance state. module StateNote # STATE_NOTE_UNSPECIFIED as the first value of State. STATE_NOTE_UNSPECIFIED = 0 # CMEK access is unavailable. PAUSED_CMEK_UNAVAILABLE = 1 # INSTANCE_RESUMING indicates that the instance was previously paused # and is under the process of being brought back. INSTANCE_RESUMING = 2 end end |
#state_note ⇒ ::Google::Cloud::SecureSourceManager::V1::Instance::StateNote (readonly)
Returns Output only. An optional field providing information about the current instance state.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 62 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # HostConfig has different instance endpoints. # @!attribute [r] html # @return [::String] # Output only. HTML hostname. # @!attribute [r] api # @return [::String] # Output only. API hostname. This is the hostname to use for **Host: Data # Plane** endpoints. # @!attribute [r] git_http # @return [::String] # Output only. Git HTTP hostname. # @!attribute [r] git_ssh # @return [::String] # Output only. Git SSH hostname. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Secure Source Manager instance state. module State # Not set. This should only be the case for incoming requests. STATE_UNSPECIFIED = 0 # Instance is being created. CREATING = 1 # Instance is ready. ACTIVE = 2 # Instance is being deleted. DELETING = 3 # Instance is paused. PAUSED = 4 end # Provides information about the current instance state. module StateNote # STATE_NOTE_UNSPECIFIED as the first value of State. STATE_NOTE_UNSPECIFIED = 0 # CMEK access is unavailable. PAUSED_CMEK_UNAVAILABLE = 1 # INSTANCE_RESUMING indicates that the instance was previously paused # and is under the process of being brought back. INSTANCE_RESUMING = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Update timestamp.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 62 class Instance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # HostConfig has different instance endpoints. # @!attribute [r] html # @return [::String] # Output only. HTML hostname. # @!attribute [r] api # @return [::String] # Output only. API hostname. This is the hostname to use for **Host: Data # Plane** endpoints. # @!attribute [r] git_http # @return [::String] # Output only. Git HTTP hostname. # @!attribute [r] git_ssh # @return [::String] # Output only. Git SSH hostname. class HostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Secure Source Manager instance state. module State # Not set. This should only be the case for incoming requests. STATE_UNSPECIFIED = 0 # Instance is being created. CREATING = 1 # Instance is ready. ACTIVE = 2 # Instance is being deleted. DELETING = 3 # Instance is paused. PAUSED = 4 end # Provides information about the current instance state. module StateNote # STATE_NOTE_UNSPECIFIED as the first value of State. STATE_NOTE_UNSPECIFIED = 0 # CMEK access is unavailable. PAUSED_CMEK_UNAVAILABLE = 1 # INSTANCE_RESUMING indicates that the instance was previously paused # and is under the process of being brought back. INSTANCE_RESUMING = 2 end end |