Class: Google::Cloud::SecureSourceManager::V1::Instance::PrivateConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

PrivateConfig includes settings for private instance.

Defined Under Namespace

Classes: CustomHostConfig

Instance Attribute Summary collapse

Instance Attribute Details

#ca_pool::String

Returns Optional. Immutable. CA pool resource, resource must in the format of projects/{project}/locations/{location}/caPools/{ca_pool}.

Returns:

  • (::String)

    Optional. Immutable. CA pool resource, resource must in the format of projects/{project}/locations/{location}/caPools/{ca_pool}.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 119

class PrivateConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom host config for the instance.
  # @!attribute [rw] html
  #   @return [::String]
  #     Required. The custom UI hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  # @!attribute [rw] api
  #   @return [::String]
  #     Required. The custom API hostname for the instance, e.g.,
  #     "api.source.internal.mycompany.com"
  # @!attribute [rw] git_ssh
  #   @return [::String]
  #     Required. The custom git ssh hostname for the instance, e.g.,
  #     "ssh.source.internal.mycompany.com"
  # @!attribute [rw] git_http
  #   @return [::String]
  #     Required. The custom git http hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  class CustomHostConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#custom_host_config::Google::Cloud::SecureSourceManager::V1::Instance::PrivateConfig::CustomHostConfig

Returns Optional. Custom host config for the instance.

Returns:



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 119

class PrivateConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom host config for the instance.
  # @!attribute [rw] html
  #   @return [::String]
  #     Required. The custom UI hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  # @!attribute [rw] api
  #   @return [::String]
  #     Required. The custom API hostname for the instance, e.g.,
  #     "api.source.internal.mycompany.com"
  # @!attribute [rw] git_ssh
  #   @return [::String]
  #     Required. The custom git ssh hostname for the instance, e.g.,
  #     "ssh.source.internal.mycompany.com"
  # @!attribute [rw] git_http
  #   @return [::String]
  #     Required. The custom git http hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  class CustomHostConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#http_service_attachment::String (readonly)

Returns Output only. Service Attachment for HTTP, resource is in the format of projects/{project}/regions/{region}/serviceAttachments/{service_attachment}.

Returns:

  • (::String)

    Output only. Service Attachment for HTTP, resource is in the format of projects/{project}/regions/{region}/serviceAttachments/{service_attachment}.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 119

class PrivateConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom host config for the instance.
  # @!attribute [rw] html
  #   @return [::String]
  #     Required. The custom UI hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  # @!attribute [rw] api
  #   @return [::String]
  #     Required. The custom API hostname for the instance, e.g.,
  #     "api.source.internal.mycompany.com"
  # @!attribute [rw] git_ssh
  #   @return [::String]
  #     Required. The custom git ssh hostname for the instance, e.g.,
  #     "ssh.source.internal.mycompany.com"
  # @!attribute [rw] git_http
  #   @return [::String]
  #     Required. The custom git http hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  class CustomHostConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#is_private::Boolean

Returns Required. Immutable. Indicate if it's private instance.

Returns:

  • (::Boolean)

    Required. Immutable. Indicate if it's private instance.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 119

class PrivateConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom host config for the instance.
  # @!attribute [rw] html
  #   @return [::String]
  #     Required. The custom UI hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  # @!attribute [rw] api
  #   @return [::String]
  #     Required. The custom API hostname for the instance, e.g.,
  #     "api.source.internal.mycompany.com"
  # @!attribute [rw] git_ssh
  #   @return [::String]
  #     Required. The custom git ssh hostname for the instance, e.g.,
  #     "ssh.source.internal.mycompany.com"
  # @!attribute [rw] git_http
  #   @return [::String]
  #     Required. The custom git http hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  class CustomHostConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#psc_allowed_projects::Array<::String>

Returns Optional. Additional allowed projects for setting up PSC connections. Instance host project is automatically allowed and does not need to be included in this list.

Returns:

  • (::Array<::String>)

    Optional. Additional allowed projects for setting up PSC connections. Instance host project is automatically allowed and does not need to be included in this list.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 119

class PrivateConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom host config for the instance.
  # @!attribute [rw] html
  #   @return [::String]
  #     Required. The custom UI hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  # @!attribute [rw] api
  #   @return [::String]
  #     Required. The custom API hostname for the instance, e.g.,
  #     "api.source.internal.mycompany.com"
  # @!attribute [rw] git_ssh
  #   @return [::String]
  #     Required. The custom git ssh hostname for the instance, e.g.,
  #     "ssh.source.internal.mycompany.com"
  # @!attribute [rw] git_http
  #   @return [::String]
  #     Required. The custom git http hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  class CustomHostConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#ssh_service_attachment::String (readonly)

Returns Output only. Service Attachment for SSH, resource is in the format of projects/{project}/regions/{region}/serviceAttachments/{service_attachment}.

Returns:

  • (::String)

    Output only. Service Attachment for SSH, resource is in the format of projects/{project}/regions/{region}/serviceAttachments/{service_attachment}.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 119

class PrivateConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom host config for the instance.
  # @!attribute [rw] html
  #   @return [::String]
  #     Required. The custom UI hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  # @!attribute [rw] api
  #   @return [::String]
  #     Required. The custom API hostname for the instance, e.g.,
  #     "api.source.internal.mycompany.com"
  # @!attribute [rw] git_ssh
  #   @return [::String]
  #     Required. The custom git ssh hostname for the instance, e.g.,
  #     "ssh.source.internal.mycompany.com"
  # @!attribute [rw] git_http
  #   @return [::String]
  #     Required. The custom git http hostname for the instance, e.g.,
  #     "git.source.internal.mycompany.com"
  class CustomHostConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end