Class: Google::Cloud::SecureSourceManager::V1::Issue

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

Metadata of an Issue.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#body::String

Returns Optional. Issue body. Provides a detailed description of the issue.

Returns:

  • (::String)

    Optional. Issue body. Provides a detailed description of the issue.



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 703

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of an issue.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open issue.
    OPEN = 1

    # A closed issue.
    CLOSED = 2
  end
end

#close_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Close timestamp (if closed). Cleared when is re-opened.

Returns:



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 703

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of an issue.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open issue.
    OPEN = 1

    # A closed issue.
    CLOSED = 2
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Creation timestamp.

Returns:



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 703

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of an issue.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open issue.
    OPEN = 1

    # A closed issue.
    CLOSED = 2
  end
end

#etag::String

Returns Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.

Returns:

  • (::String)

    Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 703

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of an issue.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open issue.
    OPEN = 1

    # A closed issue.
    CLOSED = 2
  end
end

#name::String

Returns Identifier. Unique identifier for an issue. The issue id is generated by the server. Format: projects/{project}/locations/{location}/repositories/{repository}/issues/{issue_id}.

Returns:

  • (::String)

    Identifier. Unique identifier for an issue. The issue id is generated by the server. Format: projects/{project}/locations/{location}/repositories/{repository}/issues/{issue_id}



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 703

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of an issue.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open issue.
    OPEN = 1

    # A closed issue.
    CLOSED = 2
  end
end

#state::Google::Cloud::SecureSourceManager::V1::Issue::State (readonly)

Returns Output only. State of the issue.

Returns:



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 703

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of an issue.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open issue.
    OPEN = 1

    # A closed issue.
    CLOSED = 2
  end
end

#title::String

Returns Required. Issue title.

Returns:

  • (::String)

    Required. Issue title.



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 703

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of an issue.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open issue.
    OPEN = 1

    # A closed issue.
    CLOSED = 2
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Last updated timestamp.

Returns:



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 703

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of an issue.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open issue.
    OPEN = 1

    # A closed issue.
    CLOSED = 2
  end
end