Class: Google::Cloud::SecureSourceManager::V1::ListBranchRulesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

ListBranchRulesRequest is the request to list branch rules.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. Requested page size. If unspecified, a default size of 30 will be used. The maximum value is 100; values above 100 will be coerced to 100.

Returns:

  • (::Integer)

    Optional. Requested page size. If unspecified, a default size of 30 will be used. The maximum value is 100; values above 100 will be coerced to 100.



1177
1178
1179
1180
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1177

class ListBranchRulesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



1177
1178
1179
1180
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1177

class ListBranchRulesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns:

  • (::String)


1177
1178
1179
1180
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1177

class ListBranchRulesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end