Class: Google::Cloud::SecureSourceManager::V1::ListHooksResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

ListHooksResponse is response to list hooks.

Instance Attribute Summary collapse

Instance Attribute Details

#hooks::Array<::Google::Cloud::SecureSourceManager::V1::Hook>

Returns The list of hooks.

Returns:



1081
1082
1083
1084
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1081

class ListHooksResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token identifying a page of results the server should return.

Returns:

  • (::String)

    A token identifying a page of results the server should return.



1081
1082
1083
1084
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1081

class ListHooksResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end