Class: Google::Cloud::SecureSourceManager::V1::ListInstancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

ListInstancesRequest is the request to list instances.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter for filtering results.

Returns:

  • (::String)

    Optional. Filter for filtering results.



840
841
842
843
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 840

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Hint for how to order the results.

Returns:

  • (::String)

    Optional. Hint for how to order the results.



840
841
842
843
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 840

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.



840
841
842
843
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 840

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



840
841
842
843
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 840

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for ListInstancesRequest.

Returns:

  • (::String)

    Required. Parent value for ListInstancesRequest.



840
841
842
843
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 840

class ListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end