Class: Google::Cloud::SecureSourceManager::V1::ListIssuesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

The request to list issues.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Used to filter the resulting issues list.

Returns:

  • (::String)

    Optional. Used to filter the resulting issues list.



1398
1399
1400
1401
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1398

class ListIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. If unspecified, a default size of 30 will be used. The maximum value is 100; values above 100 will be coerced to 100.

Returns:

  • (::Integer)

    Optional. Requested page size. If unspecified, a default size of 30 will be used. The maximum value is 100; values above 100 will be coerced to 100.



1398
1399
1400
1401
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1398

class ListIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



1398
1399
1400
1401
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1398

class ListIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The repository in which to list issues. Format: projects/{project_number}/locations/{location_id}/repositories/{repository_id}.

Returns:

  • (::String)

    Required. The repository in which to list issues. Format: projects/{project_number}/locations/{location_id}/repositories/{repository_id}



1398
1399
1400
1401
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1398

class ListIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end