Class: Google::Cloud::SecureSourceManager::V1::PullRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

Metadata of a PullRequest. PullRequest is the request from a user to merge a branch (head) into another branch (base).

Defined Under Namespace

Modules: State Classes: Branch

Instance Attribute Summary collapse

Instance Attribute Details

#base::Google::Cloud::SecureSourceManager::V1::PullRequest::Branch

Returns Required. The branch to merge changes in.

Returns:



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 608

class PullRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Branch represents a branch involved in a pull request.
  # @!attribute [rw] ref
  #   @return [::String]
  #     Required. Name of the branch.
  # @!attribute [r] sha
  #   @return [::String]
  #     Output only. The commit at the tip of the branch.
  class Branch
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the pull request.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open pull request.
    OPEN = 1

    # A closed pull request.
    CLOSED = 2

    # A merged pull request.
    MERGED = 3
  end
end

#body::String

Returns Optional. The pull request body. Provides a detailed description of the changes.

Returns:

  • (::String)

    Optional. The pull request body. Provides a detailed description of the changes.



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 608

class PullRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Branch represents a branch involved in a pull request.
  # @!attribute [rw] ref
  #   @return [::String]
  #     Required. Name of the branch.
  # @!attribute [r] sha
  #   @return [::String]
  #     Output only. The commit at the tip of the branch.
  class Branch
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the pull request.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open pull request.
    OPEN = 1

    # A closed pull request.
    CLOSED = 2

    # A merged pull request.
    MERGED = 3
  end
end

#close_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Close timestamp (if closed or merged). Cleared when pull request is re-opened.

Returns:



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 608

class PullRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Branch represents a branch involved in a pull request.
  # @!attribute [rw] ref
  #   @return [::String]
  #     Required. Name of the branch.
  # @!attribute [r] sha
  #   @return [::String]
  #     Output only. The commit at the tip of the branch.
  class Branch
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the pull request.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open pull request.
    OPEN = 1

    # A closed pull request.
    CLOSED = 2

    # A merged pull request.
    MERGED = 3
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Creation timestamp.

Returns:



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 608

class PullRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Branch represents a branch involved in a pull request.
  # @!attribute [rw] ref
  #   @return [::String]
  #     Required. Name of the branch.
  # @!attribute [r] sha
  #   @return [::String]
  #     Output only. The commit at the tip of the branch.
  class Branch
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the pull request.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open pull request.
    OPEN = 1

    # A closed pull request.
    CLOSED = 2

    # A merged pull request.
    MERGED = 3
  end
end

#head::Google::Cloud::SecureSourceManager::V1::PullRequest::Branch

Returns Immutable. The branch containing the changes to be merged.

Returns:



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 608

class PullRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Branch represents a branch involved in a pull request.
  # @!attribute [rw] ref
  #   @return [::String]
  #     Required. Name of the branch.
  # @!attribute [r] sha
  #   @return [::String]
  #     Output only. The commit at the tip of the branch.
  class Branch
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the pull request.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open pull request.
    OPEN = 1

    # A closed pull request.
    CLOSED = 2

    # A merged pull request.
    MERGED = 3
  end
end

#name::String (readonly)

Returns Output only. Identifier. A unique identifier for a PullRequest. The number appended at the end is generated by the server. Format: projects/{project}/locations/{location}/repositories/{repository}/pullRequests/{pull_request_id}.

Returns:

  • (::String)

    Output only. Identifier. A unique identifier for a PullRequest. The number appended at the end is generated by the server. Format: projects/{project}/locations/{location}/repositories/{repository}/pullRequests/{pull_request_id}



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 608

class PullRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Branch represents a branch involved in a pull request.
  # @!attribute [rw] ref
  #   @return [::String]
  #     Required. Name of the branch.
  # @!attribute [r] sha
  #   @return [::String]
  #     Output only. The commit at the tip of the branch.
  class Branch
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the pull request.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open pull request.
    OPEN = 1

    # A closed pull request.
    CLOSED = 2

    # A merged pull request.
    MERGED = 3
  end
end

#state::Google::Cloud::SecureSourceManager::V1::PullRequest::State (readonly)

Returns Output only. State of the pull request (open, closed or merged).

Returns:



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 608

class PullRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Branch represents a branch involved in a pull request.
  # @!attribute [rw] ref
  #   @return [::String]
  #     Required. Name of the branch.
  # @!attribute [r] sha
  #   @return [::String]
  #     Output only. The commit at the tip of the branch.
  class Branch
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the pull request.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open pull request.
    OPEN = 1

    # A closed pull request.
    CLOSED = 2

    # A merged pull request.
    MERGED = 3
  end
end

#title::String

Returns Required. The pull request title.

Returns:

  • (::String)

    Required. The pull request title.



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 608

class PullRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Branch represents a branch involved in a pull request.
  # @!attribute [rw] ref
  #   @return [::String]
  #     Required. Name of the branch.
  # @!attribute [r] sha
  #   @return [::String]
  #     Output only. The commit at the tip of the branch.
  class Branch
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the pull request.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open pull request.
    OPEN = 1

    # A closed pull request.
    CLOSED = 2

    # A merged pull request.
    MERGED = 3
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Last updated timestamp.

Returns:



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 608

class PullRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Branch represents a branch involved in a pull request.
  # @!attribute [rw] ref
  #   @return [::String]
  #     Required. Name of the branch.
  # @!attribute [r] sha
  #   @return [::String]
  #     Output only. The commit at the tip of the branch.
  class Branch
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the pull request.
  module State
    # Unspecified.
    STATE_UNSPECIFIED = 0

    # An open pull request.
    OPEN = 1

    # A closed pull request.
    CLOSED = 2

    # A merged pull request.
    MERGED = 3
  end
end