Class: Google::Cloud::SecureSourceManager::V1::PullRequestComment
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::PullRequestComment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
PullRequestComment represents a comment on a pull request.
Defined Under Namespace
Classes: Code, Comment, Position, Review
Instance Attribute Summary collapse
-
#code ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Code
Optional.
-
#comment ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Comment
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#review ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Review
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#code ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Code
Returns Optional. The comment on a code line.
Note: The following fields are mutually exclusive: code, review, comment. If a field in that set is populated, all other fields in the set will automatically be cleared.
767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 767 class PullRequestComment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review summary comment. # @!attribute [rw] action_type # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Review::ActionType] # Required. The review action type. # @!attribute [rw] body # @return [::String] # Optional. The comment body. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this review is pointing to. class Review include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review action type. module ActionType # Unspecified. ACTION_TYPE_UNSPECIFIED = 0 # A general review comment. COMMENT = 1 # Change required from this review. CHANGE_REQUESTED = 2 # Change approved from this review. APPROVED = 3 end end # The general pull request comment. # @!attribute [rw] body # @return [::String] # Required. The comment body. class Comment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The comment on a code line. # @!attribute [rw] body # @return [::String] # Required. The comment body. # @!attribute [rw] reply # @return [::String] # Optional. Input only. The PullRequestComment resource name that this # comment is replying to. # @!attribute [rw] position # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Position] # Optional. The position of the comment. # @!attribute [r] effective_root_comment # @return [::String] # Output only. The root comment of the conversation, derived from the reply # field. # @!attribute [r] resolved # @return [::Boolean] # Output only. Boolean indicator if the comment is resolved. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this code comment is pointing to. class Code include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The position of the code comment. # @!attribute [rw] path # @return [::String] # Required. The path of the file. # @!attribute [rw] line # @return [::Integer] # Required. The line number of the comment. Positive value means it's on # the new side of the diff, negative value means it's on the old side. class Position include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#comment ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Comment
Returns Optional. The general pull request comment.
Note: The following fields are mutually exclusive: comment, review, code. If a field in that set is populated, all other fields in the set will automatically be cleared.
767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 767 class PullRequestComment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review summary comment. # @!attribute [rw] action_type # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Review::ActionType] # Required. The review action type. # @!attribute [rw] body # @return [::String] # Optional. The comment body. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this review is pointing to. class Review include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review action type. module ActionType # Unspecified. ACTION_TYPE_UNSPECIFIED = 0 # A general review comment. COMMENT = 1 # Change required from this review. CHANGE_REQUESTED = 2 # Change approved from this review. APPROVED = 3 end end # The general pull request comment. # @!attribute [rw] body # @return [::String] # Required. The comment body. class Comment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The comment on a code line. # @!attribute [rw] body # @return [::String] # Required. The comment body. # @!attribute [rw] reply # @return [::String] # Optional. Input only. The PullRequestComment resource name that this # comment is replying to. # @!attribute [rw] position # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Position] # Optional. The position of the comment. # @!attribute [r] effective_root_comment # @return [::String] # Output only. The root comment of the conversation, derived from the reply # field. # @!attribute [r] resolved # @return [::Boolean] # Output only. Boolean indicator if the comment is resolved. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this code comment is pointing to. class Code include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The position of the code comment. # @!attribute [rw] path # @return [::String] # Required. The path of the file. # @!attribute [rw] line # @return [::Integer] # Required. The line number of the comment. Positive value means it's on # the new side of the diff, negative value means it's on the old side. class Position include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Creation timestamp.
767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 767 class PullRequestComment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review summary comment. # @!attribute [rw] action_type # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Review::ActionType] # Required. The review action type. # @!attribute [rw] body # @return [::String] # Optional. The comment body. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this review is pointing to. class Review include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review action type. module ActionType # Unspecified. ACTION_TYPE_UNSPECIFIED = 0 # A general review comment. COMMENT = 1 # Change required from this review. CHANGE_REQUESTED = 2 # Change approved from this review. APPROVED = 3 end end # The general pull request comment. # @!attribute [rw] body # @return [::String] # Required. The comment body. class Comment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The comment on a code line. # @!attribute [rw] body # @return [::String] # Required. The comment body. # @!attribute [rw] reply # @return [::String] # Optional. Input only. The PullRequestComment resource name that this # comment is replying to. # @!attribute [rw] position # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Position] # Optional. The position of the comment. # @!attribute [r] effective_root_comment # @return [::String] # Output only. The root comment of the conversation, derived from the reply # field. # @!attribute [r] resolved # @return [::Boolean] # Output only. Boolean indicator if the comment is resolved. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this code comment is pointing to. class Code include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The position of the code comment. # @!attribute [rw] path # @return [::String] # Required. The path of the file. # @!attribute [rw] line # @return [::Integer] # Required. The line number of the comment. Positive value means it's on # the new side of the diff, negative value means it's on the old side. class Position include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. Unique identifier for the pull request comment. The comment id
is generated by the server. Format:
projects/{project}/locations/{location}/repositories/{repository}/pullRequests/{pull_request}/pullRequestComments/{comment_id}.
767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 767 class PullRequestComment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review summary comment. # @!attribute [rw] action_type # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Review::ActionType] # Required. The review action type. # @!attribute [rw] body # @return [::String] # Optional. The comment body. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this review is pointing to. class Review include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review action type. module ActionType # Unspecified. ACTION_TYPE_UNSPECIFIED = 0 # A general review comment. COMMENT = 1 # Change required from this review. CHANGE_REQUESTED = 2 # Change approved from this review. APPROVED = 3 end end # The general pull request comment. # @!attribute [rw] body # @return [::String] # Required. The comment body. class Comment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The comment on a code line. # @!attribute [rw] body # @return [::String] # Required. The comment body. # @!attribute [rw] reply # @return [::String] # Optional. Input only. The PullRequestComment resource name that this # comment is replying to. # @!attribute [rw] position # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Position] # Optional. The position of the comment. # @!attribute [r] effective_root_comment # @return [::String] # Output only. The root comment of the conversation, derived from the reply # field. # @!attribute [r] resolved # @return [::Boolean] # Output only. Boolean indicator if the comment is resolved. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this code comment is pointing to. class Code include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The position of the code comment. # @!attribute [rw] path # @return [::String] # Required. The path of the file. # @!attribute [rw] line # @return [::Integer] # Required. The line number of the comment. Positive value means it's on # the new side of the diff, negative value means it's on the old side. class Position include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#review ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Review
Returns Optional. The review summary comment.
Note: The following fields are mutually exclusive: review, comment, code. If a field in that set is populated, all other fields in the set will automatically be cleared.
767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 767 class PullRequestComment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review summary comment. # @!attribute [rw] action_type # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Review::ActionType] # Required. The review action type. # @!attribute [rw] body # @return [::String] # Optional. The comment body. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this review is pointing to. class Review include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review action type. module ActionType # Unspecified. ACTION_TYPE_UNSPECIFIED = 0 # A general review comment. COMMENT = 1 # Change required from this review. CHANGE_REQUESTED = 2 # Change approved from this review. APPROVED = 3 end end # The general pull request comment. # @!attribute [rw] body # @return [::String] # Required. The comment body. class Comment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The comment on a code line. # @!attribute [rw] body # @return [::String] # Required. The comment body. # @!attribute [rw] reply # @return [::String] # Optional. Input only. The PullRequestComment resource name that this # comment is replying to. # @!attribute [rw] position # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Position] # Optional. The position of the comment. # @!attribute [r] effective_root_comment # @return [::String] # Output only. The root comment of the conversation, derived from the reply # field. # @!attribute [r] resolved # @return [::Boolean] # Output only. Boolean indicator if the comment is resolved. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this code comment is pointing to. class Code include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The position of the code comment. # @!attribute [rw] path # @return [::String] # Required. The path of the file. # @!attribute [rw] line # @return [::Integer] # Required. The line number of the comment. Positive value means it's on # the new side of the diff, negative value means it's on the old side. class Position include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last updated timestamp.
767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 767 class PullRequestComment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review summary comment. # @!attribute [rw] action_type # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Review::ActionType] # Required. The review action type. # @!attribute [rw] body # @return [::String] # Optional. The comment body. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this review is pointing to. class Review include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The review action type. module ActionType # Unspecified. ACTION_TYPE_UNSPECIFIED = 0 # A general review comment. COMMENT = 1 # Change required from this review. CHANGE_REQUESTED = 2 # Change approved from this review. APPROVED = 3 end end # The general pull request comment. # @!attribute [rw] body # @return [::String] # Required. The comment body. class Comment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The comment on a code line. # @!attribute [rw] body # @return [::String] # Required. The comment body. # @!attribute [rw] reply # @return [::String] # Optional. Input only. The PullRequestComment resource name that this # comment is replying to. # @!attribute [rw] position # @return [::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Position] # Optional. The position of the comment. # @!attribute [r] effective_root_comment # @return [::String] # Output only. The root comment of the conversation, derived from the reply # field. # @!attribute [r] resolved # @return [::Boolean] # Output only. Boolean indicator if the comment is resolved. # @!attribute [r] effective_commit_sha # @return [::String] # Output only. The effective commit sha this code comment is pointing to. class Code include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The position of the code comment. # @!attribute [rw] path # @return [::String] # Required. The path of the file. # @!attribute [rw] line # @return [::Integer] # Required. The line number of the comment. Positive value means it's on # the new side of the diff, negative value means it's on the old side. class Position include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |