Class: Google::Cloud::SecureSourceManager::V1::PullRequestComment::Code

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

The comment on a code line.

Instance Attribute Summary collapse

Instance Attribute Details

#body ⇒ ::String

Returns Required. The comment body.

Returns:

  • (::String) —

    Required. The comment body.



831
832
833
834
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 831

class Code
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#effective_commit_sha ⇒ ::String (readonly)

Returns Output only. The effective commit sha this code comment is pointing to.

Returns:

  • (::String) —

    Output only. The effective commit sha this code comment is pointing to.



831
832
833
834
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 831

class Code
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#effective_root_comment ⇒ ::String (readonly)

Returns Output only. The root comment of the conversation, derived from the reply field.

Returns:

  • (::String) —

    Output only. The root comment of the conversation, derived from the reply field.



831
832
833
834
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 831

class Code
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#position ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequestComment::Position

Returns Optional. The position of the comment.

Returns:



831
832
833
834
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 831

class Code
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reply ⇒ ::String

Returns Optional. Input only. The PullRequestComment resource name that this comment is replying to.

Returns:

  • (::String) —

    Optional. Input only. The PullRequestComment resource name that this comment is replying to.



831
832
833
834
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 831

class Code
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resolved ⇒ ::Boolean (readonly)

Returns Output only. Boolean indicator if the comment is resolved.

Returns:

  • (::Boolean) —

    Output only. Boolean indicator if the comment is resolved.



831
832
833
834
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 831

class Code
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end