Class: Google::Cloud::SecureSourceManager::V1::Repository::URIs

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

URIs for the repository.

Instance Attribute Summary collapse

Instance Attribute Details

#api ⇒ ::String (readonly)

Returns Output only. API is the URI for API access.

Returns:

  • (::String) —

    Output only. API is the URI for API access.



176
177
178
179
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 176

class URIs
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#git_https ⇒ ::String (readonly)

Returns Output only. git_https is the git HTTPS URI for git operations.

Returns:

  • (::String) —

    Output only. git_https is the git HTTPS URI for git operations.



176
177
178
179
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 176

class URIs
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#html ⇒ ::String (readonly)

Returns Output only. HTML is the URI for user to view the repository in a browser.

Returns:

  • (::String) —

    Output only. HTML is the URI for user to view the repository in a browser.



176
177
178
179
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 176

class URIs
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end