Class: Google::Cloud::SecureSourceManager::V1::ResolvePullRequestCommentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::ResolvePullRequestCommentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
The request to resolve multiple pull request comments.
Instance Attribute Summary collapse
-
#auto_fill ⇒ ::Boolean
Optional.
-
#names ⇒ ::Array<::String>
Required.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#auto_fill ⇒ ::Boolean
Returns Optional. If set, at least one comment in a thread is required, rest of the comments in the same thread will be automatically updated to resolved. If unset, all comments in the same thread need be present.
1704 1705 1706 1707 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1704 class ResolvePullRequestCommentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#names ⇒ ::Array<::String>
Returns Required. The names of the pull request comments to resolve. Format:
projects/{project_number}/locations/{location_id}/repositories/{repository_id}/pullRequests/{pull_request_id}/pullRequestComments/{comment_id}
Only comments from the same threads are allowed in the same request.
1704 1705 1706 1707 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1704 class ResolvePullRequestCommentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The pull request in which to resolve the pull request comments.
Format:
projects/{project_number}/locations/{location_id}/repositories/{repository_id}/pullRequests/{pull_request_id}.
1704 1705 1706 1707 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1704 class ResolvePullRequestCommentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |