Class: Google::Cloud::SecureSourceManager::V1::UpdateHookRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::UpdateHookRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
UpdateHookRequest is the request to update a hook.
Instance Attribute Summary collapse
-
#hook ⇒ ::Google::Cloud::SecureSourceManager::V1::Hook
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#hook ⇒ ::Google::Cloud::SecureSourceManager::V1::Hook
Returns Required. The hook being updated.
1128 1129 1130 1131 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1128 class UpdateHookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to specify the fields to be overwritten in the hook resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. The special value "*" means full replacement.
1128 1129 1130 1131 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1128 class UpdateHookRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |