Class: Google::Cloud::SecureSourceManager::V1::BranchRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

Metadata of a BranchRule. BranchRule is the protection rule to enforce pre-defined rules on designated branches within a repository.

Defined Under Namespace

Classes: AnnotationsEntry, Check

Instance Attribute Summary collapse

Instance Attribute Details

#allow_stale_reviews::Boolean

Returns Optional. Determines if allow stale reviews or approvals before merging to the branch.

Returns:

  • (::Boolean)

    Optional. Determines if allow stale reviews or approvals before merging to the branch.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Optional. User annotations. These attributes can only be set and used by the user. See https://google.aip.dev/128#annotations for more details such as format and size limitations.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. User annotations. These attributes can only be set and used by the user. See https://google.aip.dev/128#annotations for more details such as format and size limitations.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Create timestamp.

Returns:



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#disabled::Boolean

Returns Optional. Determines if the branch rule is disabled or not.

Returns:

  • (::Boolean)

    Optional. Determines if the branch rule is disabled or not.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#etag::String

Returns Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.

Returns:

  • (::String)

    Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#include_pattern::String

Returns Optional. The pattern of the branch that can match to this BranchRule. Specified as regex. .* for all branches. Examples: main, (main|release.). Current MVP phase only support `.` for wildcard.

Returns:

  • (::String)

    Optional. The pattern of the branch that can match to this BranchRule. Specified as regex. .* for all branches. Examples: main, (main|release.). Current MVP phase only support `.` for wildcard.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#minimum_approvals_count::Integer

Returns Optional. The minimum number of approvals required for the branch rule to be matched.

Returns:

  • (::Integer)

    Optional. The minimum number of approvals required for the branch rule to be matched.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#minimum_reviews_count::Integer

Returns Optional. The minimum number of reviews required for the branch rule to be matched.

Returns:

  • (::Integer)

    Optional. The minimum number of reviews required for the branch rule to be matched.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. A unique identifier for a BranchRule. The name should be of the format: projects/{project}/locations/{location}/repositories/{repository}/branchRules/{branch_rule}.

Returns:

  • (::String)

    Identifier. A unique identifier for a BranchRule. The name should be of the format: projects/{project}/locations/{location}/repositories/{repository}/branchRules/{branch_rule}



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#require_code_owner_approval::Boolean

Returns Optional. Determines if code owners must approve before merging to the branch.

Returns:

  • (::Boolean)

    Optional. Determines if code owners must approve before merging to the branch.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#require_comments_resolved::Boolean

Returns Optional. Determines if require comments resolved before merging to the branch.

Returns:

  • (::Boolean)

    Optional. Determines if require comments resolved before merging to the branch.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#require_linear_history::Boolean

Returns Optional. Determines if require linear history before merging to the branch.

Returns:

  • (::Boolean)

    Optional. Determines if require linear history before merging to the branch.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#require_pull_request::Boolean

Returns Optional. Determines if the branch rule requires a pull request or not.

Returns:

  • (::Boolean)

    Optional. Determines if the branch rule requires a pull request or not.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#required_status_checks::Array<::Google::Cloud::SecureSourceManager::V1::BranchRule::Check>

Returns Optional. List of required status checks before merging to the branch.

Returns:



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uid::String (readonly)

Returns Output only. Unique identifier of the repository.

Returns:

  • (::String)

    Output only. Unique identifier of the repository.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Update timestamp.

Returns:



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 525

class BranchRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Check is a type for status check.
  # @!attribute [rw] context
  #   @return [::String]
  #     Required. The context of the check.
  class Check
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end