Class: Google::Cloud::SecureSourceManager::V1::Hook

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

Metadata of a Secure Source Manager Hook.

Defined Under Namespace

Modules: HookEventType Classes: PushOption

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Create timestamp.

Returns:



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 432

class Hook
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] branch_filter
  #   @return [::String]
  #     Optional. Trigger hook for matching branches only.
  #     Specified as glob pattern. If empty or *, events for all branches are
  #     reported. Examples: main, \\{main,release*}.
  #     See https://pkg.go.dev/github.com/gobwas/glob documentation.
  class PushOption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module HookEventType
    # Unspecified.
    UNSPECIFIED = 0

    # Push events are triggered when pushing to the repository.
    PUSH = 1

    # Pull request events are triggered when a pull request is opened, closed,
    # reopened, or edited.
    PULL_REQUEST = 2
  end
end

#disabled::Boolean

Returns Optional. Determines if the hook disabled or not. Set to true to stop sending traffic.

Returns:

  • (::Boolean)

    Optional. Determines if the hook disabled or not. Set to true to stop sending traffic.



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 432

class Hook
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] branch_filter
  #   @return [::String]
  #     Optional. Trigger hook for matching branches only.
  #     Specified as glob pattern. If empty or *, events for all branches are
  #     reported. Examples: main, \\{main,release*}.
  #     See https://pkg.go.dev/github.com/gobwas/glob documentation.
  class PushOption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module HookEventType
    # Unspecified.
    UNSPECIFIED = 0

    # Push events are triggered when pushing to the repository.
    PUSH = 1

    # Pull request events are triggered when a pull request is opened, closed,
    # reopened, or edited.
    PULL_REQUEST = 2
  end
end

#events::Array<::Google::Cloud::SecureSourceManager::V1::Hook::HookEventType>

Returns Optional. The events that trigger hook on.

Returns:



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 432

class Hook
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] branch_filter
  #   @return [::String]
  #     Optional. Trigger hook for matching branches only.
  #     Specified as glob pattern. If empty or *, events for all branches are
  #     reported. Examples: main, \\{main,release*}.
  #     See https://pkg.go.dev/github.com/gobwas/glob documentation.
  class PushOption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module HookEventType
    # Unspecified.
    UNSPECIFIED = 0

    # Push events are triggered when pushing to the repository.
    PUSH = 1

    # Pull request events are triggered when a pull request is opened, closed,
    # reopened, or edited.
    PULL_REQUEST = 2
  end
end

#name::String

Returns Identifier. A unique identifier for a Hook. The name should be of the format: projects/{project}/locations/{location_id}/repositories/{repository_id}/hooks/{hook_id}.

Returns:

  • (::String)

    Identifier. A unique identifier for a Hook. The name should be of the format: projects/{project}/locations/{location_id}/repositories/{repository_id}/hooks/{hook_id}



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 432

class Hook
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] branch_filter
  #   @return [::String]
  #     Optional. Trigger hook for matching branches only.
  #     Specified as glob pattern. If empty or *, events for all branches are
  #     reported. Examples: main, \\{main,release*}.
  #     See https://pkg.go.dev/github.com/gobwas/glob documentation.
  class PushOption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module HookEventType
    # Unspecified.
    UNSPECIFIED = 0

    # Push events are triggered when pushing to the repository.
    PUSH = 1

    # Pull request events are triggered when a pull request is opened, closed,
    # reopened, or edited.
    PULL_REQUEST = 2
  end
end

#push_option::Google::Cloud::SecureSourceManager::V1::Hook::PushOption

Returns Optional. The trigger option for push events.

Returns:



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 432

class Hook
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] branch_filter
  #   @return [::String]
  #     Optional. Trigger hook for matching branches only.
  #     Specified as glob pattern. If empty or *, events for all branches are
  #     reported. Examples: main, \\{main,release*}.
  #     See https://pkg.go.dev/github.com/gobwas/glob documentation.
  class PushOption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module HookEventType
    # Unspecified.
    UNSPECIFIED = 0

    # Push events are triggered when pushing to the repository.
    PUSH = 1

    # Pull request events are triggered when a pull request is opened, closed,
    # reopened, or edited.
    PULL_REQUEST = 2
  end
end

#sensitive_query_string::String

Returns Optional. The sensitive query string to be appended to the target URI.

Returns:

  • (::String)

    Optional. The sensitive query string to be appended to the target URI.



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 432

class Hook
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] branch_filter
  #   @return [::String]
  #     Optional. Trigger hook for matching branches only.
  #     Specified as glob pattern. If empty or *, events for all branches are
  #     reported. Examples: main, \\{main,release*}.
  #     See https://pkg.go.dev/github.com/gobwas/glob documentation.
  class PushOption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module HookEventType
    # Unspecified.
    UNSPECIFIED = 0

    # Push events are triggered when pushing to the repository.
    PUSH = 1

    # Pull request events are triggered when a pull request is opened, closed,
    # reopened, or edited.
    PULL_REQUEST = 2
  end
end

#target_uri::String

Returns Required. The target URI to which the payloads will be delivered.

Returns:

  • (::String)

    Required. The target URI to which the payloads will be delivered.



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 432

class Hook
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] branch_filter
  #   @return [::String]
  #     Optional. Trigger hook for matching branches only.
  #     Specified as glob pattern. If empty or *, events for all branches are
  #     reported. Examples: main, \\{main,release*}.
  #     See https://pkg.go.dev/github.com/gobwas/glob documentation.
  class PushOption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module HookEventType
    # Unspecified.
    UNSPECIFIED = 0

    # Push events are triggered when pushing to the repository.
    PUSH = 1

    # Pull request events are triggered when a pull request is opened, closed,
    # reopened, or edited.
    PULL_REQUEST = 2
  end
end

#uid::String (readonly)

Returns Output only. Unique identifier of the hook.

Returns:

  • (::String)

    Output only. Unique identifier of the hook.



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 432

class Hook
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] branch_filter
  #   @return [::String]
  #     Optional. Trigger hook for matching branches only.
  #     Specified as glob pattern. If empty or *, events for all branches are
  #     reported. Examples: main, \\{main,release*}.
  #     See https://pkg.go.dev/github.com/gobwas/glob documentation.
  class PushOption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module HookEventType
    # Unspecified.
    UNSPECIFIED = 0

    # Push events are triggered when pushing to the repository.
    PUSH = 1

    # Pull request events are triggered when a pull request is opened, closed,
    # reopened, or edited.
    PULL_REQUEST = 2
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Update timestamp.

Returns:



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 432

class Hook
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] branch_filter
  #   @return [::String]
  #     Optional. Trigger hook for matching branches only.
  #     Specified as glob pattern. If empty or *, events for all branches are
  #     reported. Examples: main, \\{main,release*}.
  #     See https://pkg.go.dev/github.com/gobwas/glob documentation.
  class PushOption
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  module HookEventType
    # Unspecified.
    UNSPECIFIED = 0

    # Push events are triggered when pushing to the repository.
    PUSH = 1

    # Pull request events are triggered when a pull request is opened, closed,
    # reopened, or edited.
    PULL_REQUEST = 2
  end
end