Class: Google::Cloud::SecureSourceManager::V1::Instance::PrivateConfig::CustomHostConfig
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::Instance::PrivateConfig::CustomHostConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
Custom host config for the instance.
Instance Attribute Summary collapse
-
#api ⇒ ::String
Required.
-
#git_http ⇒ ::String
Required.
-
#git_ssh ⇒ ::String
Required.
-
#html ⇒ ::String
Required.
Instance Attribute Details
#api ⇒ ::String
Returns Required. The custom API hostname for the instance, e.g., "api.source.internal.mycompany.com".
140 141 142 143 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 140 class CustomHostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#git_http ⇒ ::String
Returns Required. The custom git http hostname for the instance, e.g., "git.source.internal.mycompany.com".
140 141 142 143 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 140 class CustomHostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#git_ssh ⇒ ::String
Returns Required. The custom git ssh hostname for the instance, e.g., "ssh.source.internal.mycompany.com".
140 141 142 143 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 140 class CustomHostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#html ⇒ ::String
Returns Required. The custom UI hostname for the instance, e.g., "git.source.internal.mycompany.com".
140 141 142 143 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 140 class CustomHostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |