Class: Google::Cloud::SecureSourceManager::V1::ListRepositoriesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::ListRepositoriesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
ListRepositoriesRequest is request to list repositories.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#instance ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filter results.
978 979 980 981 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 978 class ListRepositoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Optional. The name of the instance in which the repository is hosted,
formatted as
projects/{project_number}/locations/{location_id}/instances/{instance_id}.
When listing repositories via securesourcemanager.googleapis.com, this
field is required. When listing repositories via *.sourcemanager.dev, this
field is ignored.
978 979 980 981 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 978 class ListRepositoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. If unspecified, a default size of 30 will be used. The maximum value is 100; values above 100 will be coerced to 100.
978 979 980 981 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 978 class ListRepositoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
978 979 980 981 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 978 class ListRepositoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent value for ListRepositoriesRequest.
978 979 980 981 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 978 class ListRepositoriesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |