Class: Google::Cloud::SecureSourceManager::V1::OpenIssueRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::OpenIssueRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
The request to open an issue.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The current etag of the issue. If the etag is provided and does not match the current etag of the issue, opening will be blocked and an ABORTED error will be returned.
1501 1502 1503 1504 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1501 class OpenIssueRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Name of the issue to open.
The format is
projects/{project_number}/locations/{location_id}/repositories/{repository_id}/issues/{issue_id}.
1501 1502 1503 1504 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1501 class OpenIssueRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |