Class: Google::Cloud::SecureSourceManager::V1::OpenIssueRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb

Overview

The request to open an issue.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. The current etag of the issue. If the etag is provided and does not match the current etag of the issue, opening will be blocked and an ABORTED error will be returned.

Returns:

  • (::String)

    Optional. The current etag of the issue. If the etag is provided and does not match the current etag of the issue, opening will be blocked and an ABORTED error will be returned.



1474
1475
1476
1477
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1474

class OpenIssueRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. Name of the issue to open. The format is projects/{project_number}/locations/{location_id}/repositories/{repository_id}/issues/{issue_id}.

Returns:

  • (::String)

    Required. Name of the issue to open. The format is projects/{project_number}/locations/{location_id}/repositories/{repository_id}/issues/{issue_id}.



1474
1475
1476
1477
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1474

class OpenIssueRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end