Class: Google::Cloud::SecureSourceManager::V1::PullRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::PullRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
Metadata of a PullRequest. PullRequest is the request from a user to merge a branch (head) into another branch (base).
Defined Under Namespace
Modules: State Classes: Branch
Instance Attribute Summary collapse
-
#base ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequest::Branch
Required.
-
#body ⇒ ::String
Optional.
-
#close_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#head ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequest::Branch
Immutable.
-
#name ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequest::State
readonly
Output only.
-
#title ⇒ ::String
Required.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#base ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequest::Branch
Returns Required. The branch to merge changes in.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 581 class PullRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Branch represents a branch involved in a pull request. # @!attribute [rw] ref # @return [::String] # Required. Name of the branch. # @!attribute [r] sha # @return [::String] # Output only. The commit at the tip of the branch. class Branch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the pull request. module State # Unspecified. STATE_UNSPECIFIED = 0 # An open pull request. OPEN = 1 # A closed pull request. CLOSED = 2 # A merged pull request. MERGED = 3 end end |
#body ⇒ ::String
Returns Optional. The pull request body. Provides a detailed description of the changes.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 581 class PullRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Branch represents a branch involved in a pull request. # @!attribute [rw] ref # @return [::String] # Required. Name of the branch. # @!attribute [r] sha # @return [::String] # Output only. The commit at the tip of the branch. class Branch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the pull request. module State # Unspecified. STATE_UNSPECIFIED = 0 # An open pull request. OPEN = 1 # A closed pull request. CLOSED = 2 # A merged pull request. MERGED = 3 end end |
#close_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Close timestamp (if closed or merged). Cleared when pull request is re-opened.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 581 class PullRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Branch represents a branch involved in a pull request. # @!attribute [rw] ref # @return [::String] # Required. Name of the branch. # @!attribute [r] sha # @return [::String] # Output only. The commit at the tip of the branch. class Branch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the pull request. module State # Unspecified. STATE_UNSPECIFIED = 0 # An open pull request. OPEN = 1 # A closed pull request. CLOSED = 2 # A merged pull request. MERGED = 3 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Creation timestamp.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 581 class PullRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Branch represents a branch involved in a pull request. # @!attribute [rw] ref # @return [::String] # Required. Name of the branch. # @!attribute [r] sha # @return [::String] # Output only. The commit at the tip of the branch. class Branch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the pull request. module State # Unspecified. STATE_UNSPECIFIED = 0 # An open pull request. OPEN = 1 # A closed pull request. CLOSED = 2 # A merged pull request. MERGED = 3 end end |
#head ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequest::Branch
Returns Immutable. The branch containing the changes to be merged.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 581 class PullRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Branch represents a branch involved in a pull request. # @!attribute [rw] ref # @return [::String] # Required. Name of the branch. # @!attribute [r] sha # @return [::String] # Output only. The commit at the tip of the branch. class Branch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the pull request. module State # Unspecified. STATE_UNSPECIFIED = 0 # An open pull request. OPEN = 1 # A closed pull request. CLOSED = 2 # A merged pull request. MERGED = 3 end end |
#name ⇒ ::String (readonly)
Returns Output only. Identifier. A unique identifier for a PullRequest. The number
appended at the end is generated by the server. Format:
projects/{project}/locations/{location}/repositories/{repository}/pullRequests/{pull_request_id}.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 581 class PullRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Branch represents a branch involved in a pull request. # @!attribute [rw] ref # @return [::String] # Required. Name of the branch. # @!attribute [r] sha # @return [::String] # Output only. The commit at the tip of the branch. class Branch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the pull request. module State # Unspecified. STATE_UNSPECIFIED = 0 # An open pull request. OPEN = 1 # A closed pull request. CLOSED = 2 # A merged pull request. MERGED = 3 end end |
#state ⇒ ::Google::Cloud::SecureSourceManager::V1::PullRequest::State (readonly)
Returns Output only. State of the pull request (open, closed or merged).
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 581 class PullRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Branch represents a branch involved in a pull request. # @!attribute [rw] ref # @return [::String] # Required. Name of the branch. # @!attribute [r] sha # @return [::String] # Output only. The commit at the tip of the branch. class Branch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the pull request. module State # Unspecified. STATE_UNSPECIFIED = 0 # An open pull request. OPEN = 1 # A closed pull request. CLOSED = 2 # A merged pull request. MERGED = 3 end end |
#title ⇒ ::String
Returns Required. The pull request title.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 581 class PullRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Branch represents a branch involved in a pull request. # @!attribute [rw] ref # @return [::String] # Required. Name of the branch. # @!attribute [r] sha # @return [::String] # Output only. The commit at the tip of the branch. class Branch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the pull request. module State # Unspecified. STATE_UNSPECIFIED = 0 # An open pull request. OPEN = 1 # A closed pull request. CLOSED = 2 # A merged pull request. MERGED = 3 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last updated timestamp.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 581 class PullRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Branch represents a branch involved in a pull request. # @!attribute [rw] ref # @return [::String] # Required. Name of the branch. # @!attribute [r] sha # @return [::String] # Output only. The commit at the tip of the branch. class Branch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the pull request. module State # Unspecified. STATE_UNSPECIFIED = 0 # An open pull request. OPEN = 1 # A closed pull request. CLOSED = 2 # A merged pull request. MERGED = 3 end end |