Class: Google::Cloud::SecureSourceManager::V1::UnresolvePullRequestCommentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SecureSourceManager::V1::UnresolvePullRequestCommentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb
Overview
The request to unresolve multiple pull request comments.
Instance Attribute Summary collapse
-
#auto_fill ⇒ ::Boolean
Optional.
-
#names ⇒ ::Array<::String>
Required.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#auto_fill ⇒ ::Boolean
Returns Optional. If set, at least one comment in a thread is required, rest of the comments in the same thread will be automatically updated to unresolved. If unset, all comments in the same thread need be present.
1734 1735 1736 1737 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1734 class UnresolvePullRequestCommentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#names ⇒ ::Array<::String>
Returns Required. The names of the pull request comments to unresolve. Format:
projects/{project_number}/locations/{location_id}/repositories/{repository_id}/pullRequests/{pull_request_id}/pullRequestComments/{comment_id}
Only comments from the same threads are allowed in the same request.
1734 1735 1736 1737 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1734 class UnresolvePullRequestCommentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The pull request in which to resolve the pull request comments.
Format:
projects/{project_number}/locations/{location_id}/repositories/{repository_id}/pullRequests/{pull_request_id}.
1734 1735 1736 1737 |
# File 'proto_docs/google/cloud/securesourcemanager/v1/secure_source_manager.rb', line 1734 class UnresolvePullRequestCommentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |